#
# spec file for package apache-commons-codec
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2000-2010, JPackage Project
# All rights reserved.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# % bcond_without maven

%define base_name  codec
%define short_name commons-%{base_name}

Name:           apache-commons-codec
Version:        1.8
Release:        13.27
Summary:        Apache Commons Codec Package
License:        Apache-2.0
Group:          Development/Libraries/Java

Url:            http://commons.apache.org/codec/
Source0:        http://www.apache.org/dist/commons/%{base_name}/source/%{short_name}-%{version}-src.tar.gz
Source1:        http://www.apache.org/dist/commons/%{base_name}/source/%{short_name}-%{version}-src.tar.gz.asc
Source2:        apache-commons-codec.keyring
Source4:        MANIFEST.MF

BuildRequires:  ant >= 1.7
BuildRequires:  ant-junit >= 1.7
BuildRequires:  java-devel >= 1.6.0
# FIXME: mozilla-nss is necessary in order to use crypto, which is tested via junit tests
#        this should be a dependency of openjdk itself
BuildRequires:  gpg-offline
BuildRequires:  junit4
BuildRequires:  mozilla-nss

%if %with maven
BuildRequires:  apache-commons-parent >= 12
BuildRequires:  maven-surefire-maven-plugin
BuildRequires:  maven-surefire-provider-junit
BuildRequires:  maven2 >= 2.0.8
BuildRequires:  maven2-plugin-antrun
BuildRequires:  maven2-plugin-assembly
BuildRequires:  maven2-plugin-compiler
BuildRequires:  maven2-plugin-idea
BuildRequires:  maven2-plugin-install
BuildRequires:  maven2-plugin-jar
BuildRequires:  maven2-plugin-javadoc
BuildRequires:  maven2-plugin-resources
%endif
Requires(post): javapackages-tools
Requires(postun): javapackages-tools

Requires:       java >= 1.6.0
Provides:       jakarta-%{short_name} = %{version}
Obsoletes:      jakarta-%{short_name} < %{version}
Provides:       %{short_name} = %{version}
Obsoletes:      %{short_name} < %{version}

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Commons Codec is an attempt to provide definitive implementations of
commonly used encoders and decoders.

%package        javadoc
Summary:        Javadoc for %{name}
Group:          Development/Libraries/Java
Requires:       java-javadoc
Provides:       jakarta-%{short_name}-javadoc = %{version}
Obsoletes:      jakarta-%{short_name}-javadoc < %{version}
Provides:       %{short_name}-javadoc = %{version}
Obsoletes:      %{short_name}-javadoc < %{version}

%description    javadoc
Javadoc for %{name}.

%prep
%gpg_verify %{SOURCE1}
%setup -q -n %{short_name}-%{version}-src

#fixes eof encoding
sed -i 's/\r//' RELEASE-NOTES*.txt LICENSE.txt NOTICE.txt

%build
%if %with maven
export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository
mkdir -p ${MAVEN_REPO_LOCAL}
export MAVEN_OPTS="-Dmaven2.jpp.mode=true -Dmaven2.jpp.depmap.file=%{SOURCE2} -Dmaven.repo.local=${MAVEN_REPO_LOCAL} -Dproject.build.directory=$(pwd)/target"
%{_bindir}/mvn-jpp \
        -e \
        -s $(pwd)/settings.xml \
        install javadoc:javadoc
%else

export CLASSPATH=$(build-classpath junit4)
ant -Dbuild.sysclasspath=first \
  -Dconf.home=src/conf \
  -Dbuild.home=build \
  -Dsource.home=src/main/java \
  -Dtest.home=src/test/java \
  -Ddist.home=dist \
  -Dcomponent.title=%{short_name} \
  -Dcomponent.version=%{version} \
  -Dfinal.name=%{name}-%{version} \
  -Dextension.name=%{short_name} \
  test jar javadoc
%endif

%install

# jars
mkdir -p %{buildroot}%{_javadir}
%if %with maven
cp -p target/%{short_name}-%{version}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
%else
jar umf %{SOURCE4} dist/%{name}-%{version}.jar
cp -p dist/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
%endif
ln -s %{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar
ln -s %{name}-%{version}.jar %{buildroot}%{_javadir}/%{short_name}-%{version}.jar
ln -s %{name}-%{version}.jar %{buildroot}%{_javadir}/%{short_name}.jar
ln -s %{name}-%{version}.jar %{buildroot}%{_javadir}/jakarta-%{short_name}-%{version}.jar
ln -s %{name}-%{version}.jar %{buildroot}%{_javadir}/jakarta-%{short_name}.jar

# Install pom file
install -d -m 755 %{buildroot}%{_mavenpomdir}
install -p -m 644 pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{short_name}.pom
%add_maven_depmap JPP-%{short_name}.pom %{short_name}.jar -a "%{short_name}:%{short_name}"

# javadoc
mkdir -p %{buildroot}%{_javadocdir}/%{name}-%{version}
%if %with maven
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}-%{version}
%else
cp -pr dist/docs/api/* %{buildroot}%{_javadocdir}/%{name}-%{version}
%endif
ln -s %{name}-%{version} %{buildroot}%{_javadocdir}/jakarta-%{short_name}-%{version}
ln -s %{name}-%{version} %{buildroot}%{_javadocdir}/jakarta-%{short_name}
ln -s %{name}-%{version} %{buildroot}%{_javadocdir}/%{name}

%files
%defattr(0644,root,root,0755)
%doc LICENSE.txt RELEASE-NOTES.txt
%{_javadir}/*.jar
%{_mavenpomdir}/*
%{_mavendepmapfragdir}/*

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/*

%changelog
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Mon Aug 26 2013 mvyskocil@suse.com
- update to 1.8
  * Add DigestUtils.updateDigest(MessageDigest, InputStream). Thanks to Daniel Cassidy.
  * Add JUnit to test our decode with pad character in the middle.
  * Add Match Rating Approach (MRA) phonetic algorithm encoder. Thanks to crice.
  * ColognePhonetic encoder unnecessarily creates many char arrays on every loop run. Thanks to leo141.
  * Base64.encodeBase64URLSafeString doesn't add padding characters at the end.
- temporary add mozilla-nss to BR: to pass tests
- drop unecessary source files
- add signature verification
- use newer add_maven_depmap
- fix source urls
* Mon Apr  2 2012 mvyskocil@suse.cz
- add junit4 to fix a build fail
* Tue Feb 28 2012 mvyskocil@suse.cz
- update to 1.6, sync with Fedora
* Fri Sep 22 2006 skh@suse.de
- don't use icecream
- use target="1.4" for build with java 1.5
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 dbornkessel@suse.de
- Current version 1.3 from JPackage.org
